@@ -1,7 +1,8 @@
-from copy import deepcopy
+import copy
 import itertools
-import numpy as np
+from copy import deepcopy
 
+import numpy as np
 from pysimmods.generator.biogassim.config import BiogasConfig
 from pysimmods.generator.biogassim.inputs import BiogasInputs
 from pysimmods.generator.biogassim.state import BiogasState
@@ -256,3 +257,17 @@ class BiogasPlant(Generator):
         if next_state.gas_fill_percent > self.config.gas_fill_max_percent:
             next_state.burn_gas = True
             next_state.gas_critical = True
+
+    def get_state(self):
+
+        state = {"state": copy.deepcopy(self.state.__dict__)}
+        for idx, chp in enumerate(self.chps):
+            state[f"chp-{idx}"] = chp.get_state()
+        return state
+
+    def set_state(self, state):
+        for attr, value in state["state"].items():
+            setattr(self.state, attr, value)
+        # self.state = state["state"]
+        for idx, chp in enumerate(self.chps):
+            chp.set_state(state[f"chp-{idx}"])
