@@ -11,6 +11,6 @@ def _get_dict(p_max_kw):
         "p_min_kw": 0,
         "q_max_kvar": 0,
         "q_min_kvar": 0,
-        "sign_convention": "active"
+        "sign_convention": "active",
     }
     return params
