@@ -3,14 +3,16 @@ flexiblity model, which is a wrapper for all models of the
 pysimmods package.
 
 """
+import distutils
 from datetime import datetime, timedelta, timezone
 
 import mosaik_api
 import numpy as np
 import pandas as pd
 from pysimmods.mosaik import LOG
-from pysimmods.util.dateformat import GER
 from pysimmods.other.flexibility.flexibility_model import FlexibilityModel
+from pysimmods.util.dateformat import GER
+
 from .meta import META, MODELS
 
 
@@ -59,7 +61,15 @@ class FlexibilitySimulator(mosaik_api.Simulator):
         ).astimezone(timezone.utc)
 
         self.unit = sim_params.get("unit", "kw")
-        self.percent_factor = sim_params.get("percent_factor", 1.0)
+        self.use_decimal_percent = sim_params.get("use_decimal_percent", False)
+        if not isinstance(self.use_decimal_percent, bool):
+            try:
+                self.use_decimal_percent = bool(
+                    distutils.util.strtobool(self.use_decimal_percent)
+                )
+            except AttributeError:
+                self.use_decimal_percent = False
+
         self.priorize_schedule = sim_params.get("priorize_schedule", False)
         self.forecast_horizon_hours = sim_params.get(
             "forecast_horizon_hours", self.step_size / 3_600
@@ -105,14 +115,14 @@ class FlexibilitySimulator(mosaik_api.Simulator):
             self.models[eid] = FlexibilityModel(
                 MODELS[model](params, inits),
                 self.now_dt,
-                self.step_size,
-                self.forecast_horizon_hours,
-                self.flexibility_horizon_hours,
-                self.num_schedules,
-                self.rng.randint(1_000_000),
-                self.unit,
-                self.percent_factor,
-                self.priorize_schedule,
+                step_size=self.step_size,
+                forecast_horizon_hours=self.forecast_horizon_hours,
+                flexibility_horizon_hours=self.flexibility_horizon_hours,
+                num_schedules=self.num_schedules,
+                seed=self.rng.randint(1_000_000),
+                unit=self.unit,
+                use_decimal_percent=self.use_decimal_percent,
+                priorize_schedule=self.priorize_schedule,
             )
             self.num_models[model] += 1
             entities.append({"eid": eid, "type": model})
@@ -237,9 +247,12 @@ class FlexibilitySimulator(mosaik_api.Simulator):
 
                 # Aggregate inputs from different sources
                 attr_sum = 0
-                for val in src_ids.values():
-                    if val is not None:
-                        attr_sum += val
+                for src_id, val in src_ids.items():
+                    if val is None:
+                        continue
+                    if isinstance(val, np.ndarray):
+                        val = val[0]
+                    attr_sum += val
                 attr_sum /= len(src_ids)
 
                 if attr == "set_percent":
