@@ -4,8 +4,9 @@ of the pysimmods package.
 """
 import pprint
 from datetime import datetime, timedelta, timezone
-
+import distutils
 import mosaik_api
+import numpy as np
 from pysimmods.mosaik import LOG
 from pysimmods.util.dateformat import GER
 
@@ -23,6 +24,7 @@ class PysimmodsSimulator(mosaik_api.Simulator):
 
         self.step_size = None
         self.now_dt = None
+        self.percent_factor = 1.0
 
     def init(self, sid, **sim_params):
         """Called exactly ones after the simulator has been started.
@@ -53,6 +55,20 @@ class PysimmodsSimulator(mosaik_api.Simulator):
             sim_params["start_date"], GER
         ).astimezone(timezone.utc)
 
+        use_decimal_percent = sim_params.get("use_decimal_percent", False)
+        if not isinstance(use_decimal_percent, bool):
+            try:
+                use_decimal_percent = bool(
+                    distutils.util.strtobool(use_decimal_percent)
+                )
+            except AttributeError:
+                use_decimal_percent = False
+
+        if use_decimal_percent:
+            self.percent_factor = 0.01
+        else:
+            self.percent_factor = 1.0
+
         return self.meta
 
     def create(self, num, model, **model_params):
@@ -118,13 +134,18 @@ class PysimmodsSimulator(mosaik_api.Simulator):
                 # Aggregate inputs from different sources
                 attr_sum = 0
                 for src_id, val in src_ids.items():
-                    if val is not None:
-                        attr_sum += val
+                    if val is None:
+                        continue
+                    if isinstance(val, np.ndarray):
+                        val = val[0]
+                    attr_sum += val
                 attr_sum /= len(src_ids)
 
                 # Set the inputs
                 if attr == "set_percent":
-                    self.models[eid].set_percent = attr_sum
+                    self.models[eid].set_percent = (
+                        attr_sum / self.percent_factor
+                    )
                 else:
                     # Apply correction if necessary
                     if attr in ("p_set_mw", "p_th_set_mw", "q_set_mvar"):
