@@ -1,14 +1,22 @@
-from pysimmods.model.model import Model
 from pysimmods.model.config import ModelConfig
-from pysimmods.model.state import ModelState
 from pysimmods.model.inputs import ModelInputs
+from pysimmods.model.model import Model
+from pysimmods.model.state import ModelState
 
 
 class DummyConfig(ModelConfig):
     def __init__(self, params):
         super().__init__(params)
 
-        self._default_schedule = [0 for _ in range(24)]
+        self._default_schedule = [10 for _ in range(24)]
+
+    @property
+    def p_max_kw(self):
+        return 500
+
+    @property
+    def p_min_kw(self):
+        return 0
 
 
 class DummyState(ModelState):
@@ -31,8 +39,8 @@ class DummyModel(Model):
 
     @property
     def set_percent(self):
-        return self.inputs.p_set_kw
+        return self.inputs.p_set_kw / self.config.p_max_kw * 100
 
     @set_percent.setter
     def set_percent(self, value):
-        self.inputs.p_set_kw = value
+        self.inputs.p_set_kw = value * self.config.p_max_kw / 100
